api.customernetworks.v1.test_helpers.network package — Argus-Toolbelt 1.0 documentation

# api.customernetworks.v1.test_helpers.network package

## Submodules

## api.customernetworks.v1.test_helpers.network.add_customer_network module

`api.customernetworks.v1.test_helpers.network.add_customer_network.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customernetworks/v1/network, respond with HTTP 403

`api.customernetworks.v1.test_helpers.network.add_customer_network.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customernetworks/v1/network, respond with HTTP 404

`api.customernetworks.v1.test_helpers.network.add_customer_network.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customernetworks/v1/network, respond with HTTP 200

`api.customernetworks.v1.test_helpers.network.add_customer_network.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customernetworks/v1/network, respond with HTTP 401

## api.customernetworks.v1.test_helpers.network.add_customer_network_comment module

`api.customernetworks.v1.test_helpers.network.add_customer_network_comment.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customernetworks/v1/network/w+/comments, respond with HTTP 403

`api.customernetworks.v1.test_helpers.network.add_customer_network_comment.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customernetworks/v1/network/w+/comments, respond with HTTP 404

`api.customernetworks.v1.test_helpers.network.add_customer_network_comment.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customernetworks/v1/network/w+/comments, respond with HTTP 200

`api.customernetworks.v1.test_helpers.network.add_customer_network_comment.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customernetworks/v1/network/w+/comments, respond with HTTP 401

## api.customernetworks.v1.test_helpers.network.delete_customer_network module

`api.customernetworks.v1.test_helpers.network.delete_customer_network.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customernetworks/v1/network/w+, respond with HTTP 403

`api.customernetworks.v1.test_helpers.network.delete_customer_network.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customernetworks/v1/network/w+, respond with HTTP 404

`api.customernetworks.v1.test_helpers.network.delete_customer_network.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customernetworks/v1/network/w+, respond with HTTP 200

`api.customernetworks.v1.test_helpers.network.delete_customer_network.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customernetworks/v1/network/w+, respond with HTTP 401

## api.customernetworks.v1.test_helpers.network.delete_customer_network_comment module

`api.customernetworks.v1.test_helpers.network.delete_customer_network_comment.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customernetworks/v1/network/w+/comments/w+, respond with HTTP 403

`api.customernetworks.v1.test_helpers.network.delete_customer_network_comment.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customernetworks/v1/network/w+/comments/w+, respond with HTTP 404

`api.customernetworks.v1.test_helpers.network.delete_customer_network_comment.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customernetworks/v1/network/w+/comments/w+, respond with HTTP 200

`api.customernetworks.v1.test_helpers.network.delete_customer_network_comment.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customernetworks/v1/network/w+/comments/w+, respond with HTTP 401

## api.customernetworks.v1.test_helpers.network.get_customer_network module

`api.customernetworks.v1.test_helpers.network.get_customer_network.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customernetworks/v1/network/w+, respond with HTTP 403

`api.customernetworks.v1.test_helpers.network.get_customer_network.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customernetworks/v1/network/w+, respond with HTTP 404

`api.customernetworks.v1.test_helpers.network.get_customer_network.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customernetworks/v1/network/w+, respond with HTTP 200

`api.customernetworks.v1.test_helpers.network.get_customer_network.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customernetworks/v1/network/w+, respond with HTTP 401

## api.customernetworks.v1.test_helpers.network.get_customer_network_comments module

`api.customernetworks.v1.test_helpers.network.get_customer_network_comments.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customernetworks/v1/network/w+/comments, respond with HTTP 403

`api.customernetworks.v1.test_helpers.network.get_customer_network_comments.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customernetworks/v1/network/w+/comments, respond with HTTP 404

`api.customernetworks.v1.test_helpers.network.get_customer_network_comments.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customernetworks/v1/network/w+/comments, respond with HTTP 200

`api.customernetworks.v1.test_helpers.network.get_customer_network_comments.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customernetworks/v1/network/w+/comments, respond with HTTP 401

## api.customernetworks.v1.test_helpers.network.get_customer_networks module

`api.customernetworks.v1.test_helpers.network.get_customer_networks.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customernetworks/v1/network, respond with HTTP 403

`api.customernetworks.v1.test_helpers.network.get_customer_networks.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customernetworks/v1/network, respond with HTTP 404

`api.customernetworks.v1.test_helpers.network.get_customer_networks.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customernetworks/v1/network, respond with HTTP 200

`api.customernetworks.v1.test_helpers.network.get_customer_networks.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customernetworks/v1/network, respond with HTTP 401

## api.customernetworks.v1.test_helpers.network.search_customer_network module

`api.customernetworks.v1.test_helpers.network.search_customer_network.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customernetworks/v1/network/search, respond with HTTP 403

`api.customernetworks.v1.test_helpers.network.search_customer_network.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customernetworks/v1/network/search, respond with HTTP 404

`api.customernetworks.v1.test_helpers.network.search_customer_network.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customernetworks/v1/network/search, respond with HTTP 200

`api.customernetworks.v1.test_helpers.network.search_customer_network.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customernetworks/v1/network/search, respond with HTTP 401

## api.customernetworks.v1.test_helpers.network.update_customer_network module

`api.customernetworks.v1.test_helpers.network.update_customer_network.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customernetworks/v1/network/w+, respond with HTTP 403

`api.customernetworks.v1.test_helpers.network.update_customer_network.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customernetworks/v1/network/w+, respond with HTTP 404

`api.customernetworks.v1.test_helpers.network.update_customer_network.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customernetworks/v1/network/w+, respond with HTTP 200

`api.customernetworks.v1.test_helpers.network.update_customer_network.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customernetworks/v1/network/w+, respond with HTTP 401

## Module contents